@@ -1,5 +1,5 @@
-__version__ = "1.0.0"
-__keywords__ = ["unencrypted socket server client"]
+__version__ = "1.1.0"
+__keywords__ = ["unencrypted rpc socket server client"]
 
 
 if not __version__.endswith(".0"):
